<?php

namespace Drupal\fileslog\Hook;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\fileslog\FilesLogInterface;
use Drupal\fileslog\FilesLogManagerInterface;

/**
 * Hooks onto cron events.
 */
class Cron {

  /**
   * Constructs the cron hook class.
   */
  public function __construct(
    protected FileSystemInterface $fileSystem,
    protected ConfigFactoryInterface $configFactory,
    protected FilesLogManagerInterface $filesLogManager,
  ) {}

  /**
   * Executes the 'cron'-hook.
   */
  #[Hook('cron')]
  public function cron(): void {
    $max_items = (int) ($this->configFactory->get('fileslog.settings')->get('max_items') ?: 1000);
    $dir = FilesLogInterface::DIRECTORY;

    $this->fileSystem->prepareDirectory($dir, FileSystemInterface::CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS);
    $files = $this->filesLogManager->getLogFiles([], 0);
    if (count($files) > $max_items) {
      $to_delete = array_slice($files, $max_items, (count($files) - $max_items));
      foreach ($to_delete as $uri => $file) {
        $this->fileSystem->unlink($uri);
      }
    }
  }

}
