<?php

namespace Drupal\fileslog\Hook;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;

/**
 * Hooks onto form alter events.
 */
class FormAlter {

  /**
   * Constructs the form_system_logging_settings_alter hook class.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * Executes the 'form_system_logging_settings_alter'-hook.
   */
  #[Hook('form_system_logging_settings_alter')]
  public function alterSystemLoggingSettingsForm(&$form, FormStateInterface $form_state): void {
    $config = $this->configFactory->getEditable('fileslog.settings');
    $form['max_items'] = [
      '#type' => 'number',
      '#title' => t('Maximum logs'),
      '#default_value' => $config->get('max_items'),
      '#required' => TRUE,
      '#description' => t('The maximum log items to keep in the private filesystem before deleting the oldest ones.'),
    ];

    $form['#submit'][] = [$this, 'submitForm'];
  }

  /**
   * Form submission handler for system_logging_settings().
   *
   * @see static::alterForm()
   */
  public function submitForm($form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('fileslog.settings')
      ->set('max_items', $form_state->getValue('max_items'))
      ->save();
  }

}
